#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 protolude
version:              0.3.5
visibility:           public
id:                   protolude-0.3.5-8oC6g9MyQez2nvQflkWDHU
key:                  protolude-0.3.5-8oC6g9MyQez2nvQflkWDHU
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  c134158a3d2eb0bcfec22f146c0015ba
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/protolude-0.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/protolude-0.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/protolude-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.5-8oC6g9MyQez2nvQflkWDHU
depends:
    array-0.5.6.0 async-2.2.6-AoIAnpP1AE52EgJKBLwe0w base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT mtl-2.3.1
    stm-2.5.1.0 text-2.0.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

